@@ -12,7 +12,7 @@
   http://sekhon.berkeley.edu
   <sekhon@berkeley.edu>
 
-  December 22, 2007
+  August 3, 2009
 
 */
 
@@ -31,16 +31,16 @@ extern "C"
     long i;
     int isFinite=0;
     
-    PROTECT(Rx = allocVector(REALSXP, nvars));  
+    PROTECT(Rx = Rf_allocVector(REALSXP, nvars));  
     
     for (i=0; i<nvars; i++)
       {
 	REAL(Rx)[i] = X[(i+1)];
       }
     
-    PROTECT(R_fcall = lang2(fn, R_NilValue));
+    PROTECT(R_fcall = Rf_lang2(fn, R_NilValue));
     SETCADR(R_fcall, Rx);
-    fit =  REAL(eval(R_fcall, rho))[0];
+    fit =  REAL(Rf_eval(R_fcall, rho))[0];
     UNPROTECT(2);
     
     isFinite = R_finite(fit);  
@@ -68,25 +68,20 @@ extern "C"
     long i;
     int isFinite=0;
     
-    PROTECT(Rx = allocVector(REALSXP, nvars));
+    PROTECT(Rx = Rf_allocVector(REALSXP, nvars));
 
     for (i=0; i<nvars; i++)
       {
 	REAL(Rx)[i] = X[i+1];
       }
 
-    PROTECT(R_fcall = lang2(fn, R_NilValue));
+    PROTECT(R_fcall = Rf_lang2(fn, R_NilValue));
     SETCADR(R_fcall, Rx);
-    Rret = eval(R_fcall, rho);
-
-    for (i=0; i<lexical; i++)
-      {
-	ret[i] =  REAL(Rret)[i];
-      }
-    UNPROTECT(2);
+    Rret = Rf_eval(R_fcall, rho);
 
     for (i=0; i<lexical; i++)
       {
+        ret[i] =  REAL(Rret)[i];
 	isFinite = R_finite(ret[i]);  
 	if (!isFinite)
 	  {
@@ -100,25 +95,67 @@ extern "C"
 	      }
 	  }  
       }
+    UNPROTECT(2);
   } /*   void EvaluateLexical(SEXP fn, SEXP rho */
   
 
+  void EvaluateTransform(SEXP fn, SEXP rho,
+                       double *X, long nvars, long lexical, short int MinMax, double *ret)
+  {
+    SEXP R_fcall, Rx, Rret;
+    long i;
+    int isFinite=0;
+
+    PROTECT(Rx = Rf_allocVector(REALSXP, nvars));
+
+    for (i=0; i<nvars; i++)
+      {
+        REAL(Rx)[i] = X[i+1];
+      }
+
+    PROTECT(R_fcall = Rf_lang2(fn, R_NilValue));
+    SETCADR(R_fcall, Rx);
+    Rret = Rf_eval(R_fcall, rho);
+
+    for (i=0; i<lexical; i++)
+      {
+        ret[i] =  REAL(Rret)[i];
+        isFinite = R_finite(ret[i]);
+        if (!isFinite)
+          {
+            if (MinMax)
+              {
+                ret[i]=(-1*DOUBLEMAX);
+              }
+            else
+              {
+                ret[i]=(DOUBLEMAX);
+              }
+          }
+      }
+    for(i=0; i<nvars; i++) // this is the only part that differs from EvaluateLexical
+      {
+        X[(i+1)] = REAL(Rret)[(i+lexical)];
+      }
+    UNPROTECT(2);
+  } /*   void EvaluateTransform(SEXP fn, SEXP rho */
+
   void userGradientfn(SEXP fnGR, SEXP rho, double *parms, double *grad, long nvars)
   {
     SEXP Rparms, R_fcall, Rgrad;
     long i;
     
-    PROTECT(Rparms = allocVector(REALSXP, nvars));    
-    PROTECT(Rgrad  = allocVector(REALSXP, nvars));    
+    PROTECT(Rparms = Rf_allocVector(REALSXP, nvars));    
+    PROTECT(Rgrad  = Rf_allocVector(REALSXP, nvars));    
     
     for(i=0; i<nvars; i++)
       {
 	REAL(Rparms)[i] = parms[i];
       }
 
-    PROTECT(R_fcall = lang2(fnGR, R_NilValue));
+    PROTECT(R_fcall = Rf_lang2(fnGR, R_NilValue));
     SETCADR(R_fcall, Rparms);    
-    Rgrad = eval(R_fcall, rho);  
+    Rgrad = Rf_eval(R_fcall, rho);  
     
     for(i=0; i<nvars; i++)
       {
@@ -141,8 +178,8 @@ extern "C"
     /* parms = (1) MinMax, (2) nvars, (3) lexical_end, (4) [nvars/or lexical sort] */
     /* using: #define M(ROW,COL,NCOLS) (((ROW)*(NCOLS))+(COL)) */
     
-    PROTECT(MAT = allocMatrix(REALSXP, pop_size, lexical_end));
-    PROTECT(parms = allocVector(REALSXP, 4));
+    PROTECT(MAT = Rf_allocMatrix(REALSXP, pop_size, lexical_end));
+    PROTECT(parms = Rf_allocVector(REALSXP, 4));
     
     REAL(parms)[0] = MinMax;
     REAL(parms)[1] = nvars;
@@ -158,10 +195,10 @@ extern "C"
 	  }
 	}  
     
-    PROTECT(R_fcall = lang3(fnLexicalSort, MAT, parms));
+    PROTECT(R_fcall = Rf_lang3(fnLexicalSort, MAT, parms));
     SETCADR(R_fcall, parms);
     SETCADR(R_fcall, MAT);
-    MATret = eval(R_fcall, rho);  
+    MATret = Rf_eval(R_fcall, rho);  
 
     k = 0;
     for(j=0; j<lexical_end; j++)
@@ -186,9 +223,9 @@ extern "C"
     /* MinMax: 0 min, 1 max */
     /* parms = (1) MinMax, (2) UniqueCount, (3) nvars, (4) lexical */
     
-    PROTECT(Rmemory = allocMatrix(REALSXP, UniqueCount, lexical_end));
-    PROTECT(Rpopulation = allocMatrix(REALSXP, pop_size, lexical_end));
-    PROTECT(parms = allocVector(REALSXP, 3));
+    PROTECT(Rmemory = Rf_allocMatrix(REALSXP, UniqueCount, lexical_end));
+    PROTECT(Rpopulation = Rf_allocMatrix(REALSXP, pop_size, lexical_end));
+    PROTECT(parms = Rf_allocVector(REALSXP, 3));
 
     REAL(parms)[0] = MinMax;
     REAL(parms)[1] = nvars;
@@ -217,11 +254,11 @@ extern "C"
 	  }
 	}  
 
-    PROTECT(R_fcall = lang4(fnMemoryMatrixEvaluate, Rmemory, Rpopulation, parms));    
+    PROTECT(R_fcall = Rf_lang4(fnMemoryMatrixEvaluate, Rmemory, Rpopulation, parms));    
     SETCADR(R_fcall, parms);
     SETCADR(R_fcall, Rpopulation);
     SETCADR(R_fcall, Rmemory);
-    Rret = eval(R_fcall, rho);      
+    Rret = Rf_eval(R_fcall, rho);      
 
     UniqueCount = (long) REAL(Rret)[0];
     k =1;
